==> boostcrm-widget-1.0.2.tgz: package/es/store/reducers/message.reducer.js <==
import _extends from 'babel-runtime/helpers/extends';
import _findLastIndex from 'lodash/findLastIndex';
import _size from 'lodash/size';
import _unionBy from 'lodash/unionBy';
import _find from 'lodash/find';
import _get from 'lodash/get';
import _pick from 'lodash/pick';
import _isEmpty from 'lodash/isEmpty';

var _messageReducer;

import { createReducer } from '../../commons/utils/store';
import { handleCorrectMessages } from '../../commons/utils/correct-message';
import { MESSAGE_STATUS } from '../../commons/constants/message-status';
import { SENDER_TYPES } from '../../commons/constants/sender-types';
import { sendTextMessageRequest, receiveMessageFromAdmin, sendAttachmentRequest, sendAttachmentSuccess, sendAttachmentError, getMessagesRequest, getMessagesSuccess, getMessagesError, resetNumberOfNewMessages, receiveCreatedMessageNotification, toggleChatRequest, onScrollToBottom } from '../actions';

var MAX_NUMBER_OF_MESSAGES = 20;
var defaultIdForSubscriber = 'subscriber';
var defaultIdForBot = 'bot';
var getSenderId = function getSenderId(message) {
  if (!message) return;
  if (message.senderType === SENDER_TYPES.BOT) {
    return defaultIdForBot;
  }

  if (message.senderType === SENDER_TYPES.SUBSCRIBER) {
    return defaultIdForSubscriber;
  }

  return message.adminId || defaultIdForBot;
};
function getMessageFromPayload(payload) {
  var type = _get(payload, 'type');
  if (type === 'text') {
    return _extends({}, _pick(payload, ['id', 'type', 'status', 'externalId']), {
      content: _get(payload, 'content.text') || _get(payload, 'content')
    });
  }
  return _pick(payload, ['id', 'type', 'status', 'content', 'externalId']);
}

function shortifyMessages(messages) {
  // return messages;
  if (!messages) return [];
  if (_size(messages) > MAX_NUMBER_OF_MESSAGES) {
    // console.log('messages before: ', size(messages));
    var results = messages.slice(_size(messages) - MAX_NUMBER_OF_MESSAGES);
    // console.log('messages after: ', size(results));
    return results;
  }
  return messages;
}

function mergeOrAppendNewMessages(oldMessages, newMessages) {
  var result = _unionBy(oldMessages, newMessages, function (m) {
    return m.message.id;
  }).sort(function (a, b) {
    return a.message.id - b.message.id;
  });
  // console.log('mergeOrAppendNewMessages: ');
  // console.log('newMessages: ', JSON.stringify(newMessages));
  // console.log('oldMessages: ', JSON.stringify(oldMessages));
  // Merge new fields to the existing one

  var _loop = function _loop(i, item) {
    if (item.message.id) {
      var foundItem = _find(newMessages, function (m) {
        return m.message.id === item.message.id;
      });
      if (foundItem) {
        // console.log('found item: ', item.message.id);
        result[i] = _extends({}, item, {
          senderType: _get(foundItem, 'senderType') || _get(item, 'senderType'), // For hot fix
          message: _extends({}, item.message, foundItem.message)
        });
      } else {
        // console.log('not found: ', item.message.id);
      }
    }
  };

  for (var _iterator = result.entries(), _isArray = Array.isArray(_iterator), _i = 0, _iterator = _isArray ? _iterator : _iterator[Symbol.iterator]();;) {
    var _ref2;

    if (_isArray) {
      if (_i >= _iterator.length) break;
      _ref2 = _iterator[_i++];
    } else {
      _i = _iterator.next();
      if (_i.done) break;
      _ref2 = _i.value;
    }

    var _ref = _ref2;
    var i = _ref[0];
    var item = _ref[1];

    _loop(i, item);
  }

  return handleCorrectMessages(result);
}

function getNumberOfNewMessages(messages) {
  var numberOfNewMessages = 0;
  var lastMessageRead = _findLastIndex(messages, ['status', MESSAGE_STATUS.READ]);
  (messages || []).forEach(function (m, index) {
    if (index > lastMessageRead && m.senderId !== 'subscriber' && _get(m, ['message', 'type']) !== 'delay') {
      numberOfNewMessages = numberOfNewMessages + 1;
    }
  });
  return numberOfNewMessages;
}

var initialState = {
  rawMessages: [],
  messages: [],
  participants: [{
    id: defaultIdForBot,
    name: 'bot',
    avatar: '',
    side: 'left',
    isShowAvatar: true
  }, {
    id: defaultIdForSubscriber,
    name: 'user01',
    avatar: '',
    side: 'right',
    isShowAvatar: false
  }],
  isLoadingMessage: false,
  isLoadingMessageHistory: false,
  numberOfNewMessages: 0
};

var messageReducer = (_messageReducer = {}, _messageReducer[onScrollToBottom] = function (state) {
  // console.log('onScrollToBottom');
  if (state.isLoadingMessageHistory) {
    return state;
  }
  return _extends({}, state, { messages: shortifyMessages(state.messages) });
}, _messageReducer[toggleChatRequest] = function (state, _ref3) {
  var payload = _ref3.payload;

  return _extends({}, state, {
    numberOfNewMessages: payload === true ? 0 : getNumberOfNewMessages(state.messages)
  });
}, _messageReducer[sendTextMessageRequest] = function (state, _ref4) {
  var payload = _ref4.payload;

  var newMessages = [].concat(state.messages, [{
    senderId: defaultIdForSubscriber,
    senderType: SENDER_TYPES.SUBSCRIBER,
    message: getMessageFromPayload(payload)
  }]);

  return _extends({}, state, {
    messages: newMessages,
    numberOfNewMessages: getNumberOfNewMessages(newMessages)
  });
}, _messageReducer[receiveCreatedMessageNotification] = function (state, _ref5) {
  var payload = _ref5.payload;
  var id = payload.id,
      status = payload.status,
      message = payload.message;

  return _extends({}, state, {
    messages: state.messages.map(function (item) {
      if (item.message.id) return item;
      if (_get(item, 'message.externalId') === _get(message, 'externalId')) {
        return _extends({}, item, {
          message: getMessageFromPayload(_extends({ id: id, status: status }, message))
        });
      }
      return item;
    })
  });
}, _messageReducer[receiveMessageFromAdmin] = function (state, _ref6) {
  var payload = _ref6.payload;

  var messages = mergeOrAppendNewMessages(state.messages, [{
    senderId: defaultIdForBot,
    senderType: _get(payload, 'sender.isBot') ? SENDER_TYPES.BOT : SENDER_TYPES.ADMIN,
    message: getMessageFromPayload(payload)
  }]);

  return _extends({}, state, {
    messages: messages,
    // messages: shortifyMessages(messages),
    numberOfNewMessages: getNumberOfNewMessages(messages)
  });
}, _messageReducer[sendAttachmentRequest] = function (state, _ref7) {
  var payload = _ref7.payload;

  return _extends({}, state, {
    messages: [].concat(state.messages, [{
      senderId: defaultIdForSubscriber,
      senderType: SENDER_TYPES.SUBSCRIBER,
      message: getMessageFromPayload(payload)
    }])
  });
}, _messageReducer[sendAttachmentSuccess] = function (state, action) {
  // Old messages
  var listMessages = [].concat(state.messages);
  // New messages
  var newMessages = _get(action, ['payload', 'res']);
  // Append new messages
  (newMessages || []).map(function (newMessage) {
    var externalId = _get(newMessage, 'externalId');
    listMessages = listMessages.map(function (mes) {
      var originalExternalId = _get(mes, ['message', 'externalId']);
      if (Number(originalExternalId) === Number(externalId)) {
        return {
          senderId: defaultIdForSubscriber,
          senderType: SENDER_TYPES.SUBSCRIBER,
          message: getMessageFromPayload(_get(newMessage, 'message'))
        };
      }
      return mes;
    });
  });
  return _extends({}, state, {
    messages: listMessages
  });
}, _messageReducer[sendAttachmentError] = function (state, action) {
  return _extends({}, state);
}, _messageReducer[getMessagesRequest] = function (state, _ref8) {
  var payload = _ref8.payload;

  return _extends({}, state, {
    isLoadingMessage: true,
    isLoadingMessageHistory: payload.isLoadingMessageHistory
  });
}, _messageReducer[getMessagesSuccess] = function (state, _ref9) {
  var payload = _ref9.payload;

  var messages = payload || [];
  if (_isEmpty(messages)) return _extends({}, state, {
    isLoadingMessage: true,
    isLoadingMessageHistory: false,
    numberOfNewMessages: getNumberOfNewMessages(state.message)
  });

  var newMessages = mergeOrAppendNewMessages(state.messages, messages.map(function (m) {
    return {
      senderId: getSenderId(m),
      senderType: m.senderType,
      message: getMessageFromPayload(_extends({ id: m.id, status: m.status }, m.message))
    };
  }));
  return _extends({}, state, {
    isLoadingMessage: true,
    isLoadingMessageHistory: false,
    messages: newMessages,
    numberOfNewMessages: getNumberOfNewMessages(newMessages)
  });
}, _messageReducer[resetNumberOfNewMessages] = function (state) {
  var lastMessage = state.messages.pop();
  return _extends({}, state, {
    messages: [].concat(state.messages, [_extends({}, lastMessage, { status: MESSAGE_STATUS.READ })]),
    numberOfNewMessages: 0
  });
}, _messageReducer);

export default (function () {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments[1];
  return createReducer(messageReducer, state, action);
});

==> boostcrm-widget-1.0.8.tgz: package/es/store/reducers/message.reducer.js <==
import _extends from "@babel/runtime/helpers/extends";
import _findLastIndex from "lodash/findLastIndex";
import _size from "lodash/size";
import _unionBy from "lodash/unionBy";
import _find from "lodash/find";
import _get from "lodash/get";
import _pick from "lodash/pick";
import _isEmpty from "lodash/isEmpty";

var _messageReducer;

function _createForOfIteratorHelperLoose(o, allowArrayLike) { var it = typeof Symbol !== "undefined" && o[Symbol.iterator] || o["@@iterator"]; if (it) return (it = it.call(o)).next.bind(it); if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; return function () { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

import { createReducer } from '../../commons/utils/store';
import { handleCorrectMessages } from '../../commons/utils/correct-message';
import { MESSAGE_STATUS } from '../../commons/constants/message-status';
import { SENDER_TYPES } from '../../commons/constants/sender-types';
import { sendTextMessageRequest, receiveMessageFromAdmin, sendAttachmentRequest, sendAttachmentSuccess, sendAttachmentError, getMessagesRequest, getMessagesSuccess, getMessagesError, resetNumberOfNewMessages, receiveCreatedMessageNotification, toggleChatRequest, onScrollToBottom } from '../actions';
var MAX_NUMBER_OF_MESSAGES = 20;
var defaultIdForSubscriber = 'subscriber';
var defaultIdForBot = 'bot';

var getSenderId = function getSenderId(message) {
  if (!message) return;

  if (message.senderType === SENDER_TYPES.BOT) {
    return defaultIdForBot;
  }

  if (message.senderType === SENDER_TYPES.SUBSCRIBER) {
    return defaultIdForSubscriber;
  }

  return message.adminId || defaultIdForBot;
};

function getMessageFromPayload(payload) {
  var type = _get(payload, 'type');

  if (type === 'text') {
    return _extends({}, _pick(payload, ['id', 'type', 'status', 'externalId']), {
      content: _get(payload, 'content.text') || _get(payload, 'content')
    });
  }

  return _pick(payload, ['id', 'type', 'status', 'content', 'externalId']);
}

function shortifyMessages(messages) {
  // return messages;
  if (!messages) return [];

  if (_size(messages) > MAX_NUMBER_OF_MESSAGES) {
    // console.log('messages before: ', size(messages));
    var results = messages.slice(_size(messages) - MAX_NUMBER_OF_MESSAGES); // console.log('messages after: ', size(results));

    return results;
  }

  return messages;
}

function mergeOrAppendNewMessages(oldMessages, newMessages) {
  var result = _unionBy(oldMessages, newMessages, function (m) {
    return m.message.id;
  }).sort(function (a, b) {
    return a.message.id - b.message.id;
  }); // console.log('mergeOrAppendNewMessages: ');
  // console.log('newMessages: ', JSON.stringify(newMessages));
  // console.log('oldMessages: ', JSON.stringify(oldMessages));
  // Merge new fields to the existing one


  var _loop = function _loop() {
    var _step$value = _step.value,
        i = _step$value[0],
        item = _step$value[1];

    if (item.message.id) {
      var foundItem = _find(newMessages, function (m) {
        return m.message.id === item.message.id;
      });

      if (foundItem) {
        // console.log('found item: ', item.message.id);
        result[i] = _extends({}, item, {
          senderType: _get(foundItem, 'senderType') || _get(item, 'senderType'),
          // For hot fix
          message: _extends({}, item.message, foundItem.message)
        });
      } else {// console.log('not found: ', item.message.id);
      }
    }
  };

  for (var _iterator = _createForOfIteratorHelperLoose(result.entries()), _step; !(_step = _iterator()).done;) {
    _loop();
  }

  return handleCorrectMessages(result);
}

function getNumberOfNewMessages(messages) {
  var numberOfNewMessages = 0;

  var lastMessageRead = _findLastIndex(messages, ['status', MESSAGE_STATUS.READ]);

  (messages || []).forEach(function (m, index) {
    if (index > lastMessageRead && m.senderId !== 'subscriber' && _get(m, ['message', 'type']) !== 'delay') {
      numberOfNewMessages = numberOfNewMessages + 1;
    }
  });
  return numberOfNewMessages;
}

var initialState = {
  rawMessages: [],
  messages: [],
  participants: [{
    id: defaultIdForBot,
    name: 'bot',
    avatar: '',
    side: 'left',
    isShowAvatar: true
  }, {
    id: defaultIdForSubscriber,
    name: 'user01',
    avatar: '',
    side: 'right',
    isShowAvatar: false
  }],
  isLoadingMessage: false,
  isLoadingMessageHistory: false,
  numberOfNewMessages: 0
};
var messageReducer = (_messageReducer = {}, _messageReducer[onScrollToBottom] = function (state) {
  // console.log('onScrollToBottom');
  if (state.isLoadingMessageHistory) {
    return state;
  }

  return _extends({}, state, {
    messages: shortifyMessages(state.messages)
  });
}, _messageReducer[toggleChatRequest] = function (state, _ref) {
  var payload = _ref.payload;
  return _extends({}, state, {
    numberOfNewMessages: payload === true ? 0 : getNumberOfNewMessages(state.messages)
  });
}, _messageReducer[sendTextMessageRequest] = function (state, _ref2) {
  var payload = _ref2.payload;
  var newMessages = [].concat(state.messages, [{
    senderId: defaultIdForSubscriber,
    senderType: SENDER_TYPES.SUBSCRIBER,
    message: getMessageFromPayload(payload)
  }]);
  return _extends({}, state, {
    messages: newMessages,
    numberOfNewMessages: getNumberOfNewMessages(newMessages)
  });
}, _messageReducer[receiveCreatedMessageNotification] = function (state, _ref3) {
  var payload = _ref3.payload;
  var id = payload.id,
      status = payload.status,
      message = payload.message;
  return _extends({}, state, {
    messages: state.messages.map(function (item) {
      if (item.message.id) return item;

      if (_get(item, 'message.externalId') === _get(message, 'externalId')) {
        return _extends({}, item, {
          message: getMessageFromPayload(_extends({
            id: id,
            status: status
          }, message))
        });
      }

      return item;
    })
  });
}, _messageReducer[receiveMessageFromAdmin] = function (state, _ref4) {
  var payload = _ref4.payload;
  var messages = mergeOrAppendNewMessages(state.messages, [{
    senderId: defaultIdForBot,
    senderType: _get(payload, 'sender.isBot') ? SENDER_TYPES.BOT : SENDER_TYPES.ADMIN,
    message: getMessageFromPayload(payload)
  }]);
  return _extends({}, state, {
    messages: messages,
    // messages: shortifyMessages(messages),
    numberOfNewMessages: getNumberOfNewMessages(messages)
  });
}, _messageReducer[sendAttachmentRequest] = function (state, _ref5) {
  var payload = _ref5.payload;
  return _extends({}, state, {
    messages: [].concat(state.messages, [{
      senderId: defaultIdForSubscriber,
      senderType: SENDER_TYPES.SUBSCRIBER,
      message: getMessageFromPayload(payload)
    }])
  });
}, _messageReducer[sendAttachmentSuccess] = function (state, action) {
  // Old messages
  var listMessages = [].concat(state.messages); // New messages

  var newMessages = _get(action, ['payload', 'res']); // Append new messages


  (newMessages || []).map(function (newMessage) {
    var externalId = _get(newMessage, 'externalId');

    listMessages = listMessages.map(function (mes) {
      var originalExternalId = _get(mes, ['message', 'externalId']);

      if (Number(originalExternalId) === Number(externalId)) {
        return {
          senderId: defaultIdForSubscriber,
          senderType: SENDER_TYPES.SUBSCRIBER,
          message: getMessageFromPayload(_get(newMessage, 'message'))
        };
      }

      return mes;
    });
  });
  return _extends({}, state, {
    messages: listMessages
  });
}, _messageReducer[sendAttachmentError] = function (state, action) {
  return _extends({}, state);
}, _messageReducer[getMessagesRequest] = function (state, _ref6) {
  var payload = _ref6.payload;
  return _extends({}, state, {
    isLoadingMessage: true,
    isLoadingMessageHistory: payload.isLoadingMessageHistory
  });
}, _messageReducer[getMessagesSuccess] = function (state, _ref7) {
  var payload = _ref7.payload;
  var messages = payload || [];
  if (_isEmpty(messages)) return _extends({}, state, {
    isLoadingMessage: true,
    isLoadingMessageHistory: false,
    numberOfNewMessages: getNumberOfNewMessages(state.message)
  });
  var newMessages = mergeOrAppendNewMessages(state.messages, messages.map(function (m) {
    return {
      senderId: getSenderId(m),
      senderType: m.senderType,
      message: getMessageFromPayload(_extends({
        id: m.id,
        status: m.status
      }, m.message))
    };
  }));
  return _extends({}, state, {
    isLoadingMessage: true,
    isLoadingMessageHistory: false,
    messages: newMessages,
    numberOfNewMessages: getNumberOfNewMessages(newMessages)
  });
}, _messageReducer[resetNumberOfNewMessages] = function (state) {
  var lastMessage = state.messages.pop();
  return _extends({}, state, {
    messages: [].concat(state.messages, [_extends({}, lastMessage, {
      status: MESSAGE_STATUS.READ
    })]),
    numberOfNewMessages: 0
  });
}, _messageReducer);
export default (function (state, action) {
  if (state === void 0) {
    state = initialState;
  }

  return createReducer(messageReducer, state, action);
});
